# Mexc API

Pretty and fully asynchronous wrapper for <a href="https://mexcdevelop.github.io/apidocs/spot_v3_en">MEXC API</a>

## TODO:
 - Add all methods (split by category)
 - Add <a href="https://mexcdevelop.github.io/apidocs/spot_v3_en/#websocket-market-streams">WebSocket Support</a>

> [!CAUTION]
> This wrapper is currently being worked on, please note that the API may change in any version.
